.. SPDX-FileCopyrightText: 2022 geisserml <geisserml@gmail.com>
.. SPDX-License-Identifier: CC-BY-4.0

Shell API
=========

pypdfium2 can also be used from the command-line.


Main help
*********
``pypdfium2 --help``

.. program-output:: pypdfium2 --help


Version
*******
``pypdfium2 --version``

.. program-output:: pypdfium2 --version


Renderer
********
``pypdfium2 render --help``

.. program-output:: pypdfium2 render --help


Table of Contents Reader
************************
``pypdfium2 toc --help``

.. program-output:: pypdfium2 toc --help


Merger
******
``pypdfium2 merge --help``

.. program-output:: pypdfium2 merge --help


Page Tiler
**********
``pypdfium2 tile --help``

.. program-output:: pypdfium2 tile --help


Text Extractor
**************
``pypdfium2 extract-text --help``

.. program-output:: pypdfium2 extract-text --help


Page Object Finder
******************
``pypdfium2 find-pageobjects --help``

.. program-output:: pypdfium2 find-pageobjects --help
